@@ -25,7 +25,6 @@
 #include "InfoData.h"
 
 #ifdef Q_OS_ANDROID
-#include <QtAndroid>
 #include <QGuiApplication>
 
 // WindowManager.LayoutParams
@@ -59,7 +58,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     //Extra debug if needed
     //qputenv("QML_IMPORT_TRACE", "1");
     QQmlApplicationEngine engine;
-    
+
     qmlRegisterType<InfoData>("Data", 1, 0, "InfoData");
 
     //we want different main files on desktop or mobile
@@ -76,15 +75,15 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return -1;
     }
 
-    //HACK to color the system bar on Android, use qtandroidextras and call the appropriate Java methods 
+    //HACK to color the system bar on Android, use qtandroidextras and call the appropriate Java methods
 #ifdef Q_OS_ANDROID
-    QtAndroid::runOnAndroidThread([=]() {
-        QAndroidJniObject window = QtAndroid::androidActivity().callObjectMethod("getWindow", "()Landroid/view/Window;");
-        window.callMethod<void>("addFlags", "(I)V", FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
-        window.callMethod<void>("clearFlags", "(I)V", FLAG_TRANSLUCENT_STATUS);
-        window.callMethod<void>("setStatusBarColor", "(I)V", QColor("#2196f3").rgba());
-        window.callMethod<void>("setNavigationBarColor", "(I)V", QColor("#2196f3").rgba());
-    });
+    //QtAndroid::runOnAndroidThread([=]() {
+    //    QAndroidJniObject window = QtAndroid::androidActivity().callObjectMethod("getWindow", "()Landroid/view/Window;");
+    //    window.callMethod<void>("addFlags", "(I)V", FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
+    //    window.callMethod<void>("clearFlags", "(I)V", FLAG_TRANSLUCENT_STATUS);
+    //    window.callMethod<void>("setStatusBarColor", "(I)V", QColor("#2196f3").rgba());
+    //    window.callMethod<void>("setNavigationBarColor", "(I)V", QColor("#2196f3").rgba());
+    //});
 #endif
 
     return app.exec();
